@@ -260,13 +260,13 @@ List poppler_pdf_data (RawVector x, bool get_font_info, std::string opw, std::st
 }
 
 // [[Rcpp::export]]
-CharacterVector poppler_pdf_text (RawVector x, std::string opw, std::string upw) {
+CharacterVector poppler_pdf_text (RawVector x, std::string opw, std::string upw, bool raw = false) {
   std::unique_ptr<poppler::document> doc(read_raw_pdf(x, opw, upw));
   CharacterVector out(doc->pages());
   for(int i = 0; i < doc->pages(); i++){
     std::unique_ptr<poppler::page> p(doc->create_page(i));
     if(!p) continue; //missing page
-    page::text_layout_enum show_text_layout = page::physical_layout;
+    page::text_layout_enum show_text_layout = raw ? page::raw_order_layout : page::physical_layout;
 
     /* media_box includes text in margins: https://github.com/ropensci/pdftools/issues/67 */
     rectf target(p->page_rect(media_box));
@@ -359,10 +359,17 @@ List poppler_pdf_files (RawVector x, std::string opw, std::string upw) {
       RawVector res(data.size());
       std::copy(data.begin(), data.end(), res.begin());
       out.push_back(List::create(
+#if VERSION_AT_LEAST(25, 10)
+        _["name"] = ustring_to_r(file->unicodeName()),
+        _["mime"] = file->mime_type(),
+        _["created"] = Datetime(file->creation_date_t()),
+        _["modified"] = Datetime(file->modification_date_t()),
+#else
         _["name"] = file->name(),
         _["mime"] = file->mime_type(),
         _["created"] = Datetime(file->creation_date()),
         _["modified"] = Datetime(file->modification_date()),
+#endif
         _["description"] = ustring_to_r(file->description()),
         _["data"] = res
       ));
